==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebNavbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavbarDescription } from "./WebNavbarDescription";
/**
 * @hidden
 */
var WebNavbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebNavbarDescriptionMetadata, _super);
    function WebNavbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavbarDescriptionMetadata.b = function (a) {
        if (WebNavbarDescriptionMetadata.a == null) {
            WebNavbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavbarDescriptionMetadata.c(WebNavbarDescriptionMetadata.a);
        }
        if (a.j(WebNavbarDescriptionMetadata.a)) {
            return;
        }
        a.y(WebNavbarDescriptionMetadata.a);
    };
    WebNavbarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Navbar");
        a.item("__tagNameWC", "String:igc-navbar");
    };
    WebNavbarDescriptionMetadata.d = function (a) {
        WebNavbarDescriptionMetadata.b(a);
        a.aa("WebNavbar", function () { return new WebNavbarDescription(); });
        a.z("WebNavbar", WebNavbarDescriptionMetadata.a);
    };
    WebNavbarDescriptionMetadata.$t = markType(WebNavbarDescriptionMetadata, 'WebNavbarDescriptionMetadata');
    WebNavbarDescriptionMetadata.a = null;
    return WebNavbarDescriptionMetadata;
}(Base));
export { WebNavbarDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebNavbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavbarDescription } from "./WebNavbarDescription";
/**
 * @hidden
 */
var WebNavbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebNavbarDescriptionMetadata, _super);
    function WebNavbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavbarDescriptionMetadata.b = function (a) {
        if (WebNavbarDescriptionMetadata.a == null) {
            WebNavbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavbarDescriptionMetadata.c(WebNavbarDescriptionMetadata.a);
        }
        if (a.k(WebNavbarDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebNavbarDescriptionMetadata.a);
    };
    WebNavbarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Navbar");
        a.item("__tagNameWC", "String:igc-navbar");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebNavbarDescriptionMetadata.d = function (a) {
        WebNavbarDescriptionMetadata.b(a);
        a.ac("WebNavbar", function () { return new WebNavbarDescription(); });
        a.ab("WebNavbar", WebNavbarDescriptionMetadata.a);
    };
    WebNavbarDescriptionMetadata.$t = markType(WebNavbarDescriptionMetadata, 'WebNavbarDescriptionMetadata');
    WebNavbarDescriptionMetadata.a = null;
    return WebNavbarDescriptionMetadata;
}(Base));
export { WebNavbarDescriptionMetadata };
